@@ -64,6 +64,8 @@ if (!$snmptrapd) {
     exit 1
 }
 
+printf "Listening on %s:%i\n", $snmptrapd->server->sockhost, $snmptrapd->server->sockport;
+
 while (1) {
     my $trap = $snmptrapd->get_trap();
 
@@ -82,8 +84,8 @@ while (1) {
             $p = $trap->datagram(1)
         } else {
             $p = sprintf "%s\t%i\t%i\t%s\t%s\t", 
-                             $trap->peeraddr, 
-                             $trap->peerport, 
+                             $trap->remoteaddr, 
+                             $trap->remoteport, 
                              $trap->version, 
                              $trap->community,
                              $trap->pdu_type;
